# React Native Boilerplate

Neosyn go-to boilerplate for new mobile projects.

## Features

- [React Native](https://reactnative.dev/) The React Native Framework for Production.
- [Jest](https://github.com/facebook/jest): tool to test React components and hooks.
- [Prettier](https://github.com/prettier/prettier): opinionated code formatter.
- [Husky](https://github.com/typicode/husky) + [lint-staged](https://github.com/okonet/lint-staged): git hooks to run commands before git events (commit, push, etc).
- [Codegen](https://the-guild.dev/graphql/codegen/docs/guides/react-vue): GraphQL API code generation (GraphQL.schema).
- [react-i18next](https://react.i18next.com/) is a powerful internationalization framework for React/React Native
- [commit-lint](https://commitlint.js.org/#/)
- [react-native-dotenv](https://github.com/goatandsheep/react-native-dotenv) Load environment variables using import statements.

## Extensions vscode
- [Eslint](https://marketplace.visualstudio.com/items?itemName=dbaeumer.vscode-eslint): ESLint helps developers identify and fix code errors, vulnerabilities, and coding styles that do not conform to project guidelines.
- [Prettier](https://marketplace.visualstudio.com/items?itemName=esbenp.prettier-vscode) Prettier is a code formatting tool that helps developers write cleaner and more readable code.

### Coming soon

- [Github Actions](https://github.com/features/actions): add Github Actions task to add CI/CD workflow.

### Commitlint

For each type add first id jira e.g. ``PC-6 | docs: add readme ``

Commonly used commit types from [Conventional Commit Types](https://github.com/commitizen/conventional-commit-types)

| Type     | Description                                                                      |
| :------- | :------------------------------------------------------------------------------- |
| feat     | A new feature                                                                    |
| fix      | A bug fix                                                                        |
| docs     | Documentation only changes                                                       |
| style    | Changes that do not affect the meaning of the code (white-space, formatting etc) |
| refactor | A code change that neither fixes a bug nor adds a feature                        |
| perf     | A code change that improves performance                                          |
| test     | Adding missing tests or correcting existing tests                                |
| build    | Changes that affect the build system or external dependencies                    |
| ci       | Changes to our CI configuration files and scripts                                |
| chore    | Other changes that don't modify src or test files                                |
| revert   | Reverts a previous commit                                                        |

#### GraphQL API

**@graphql-codegen/cli**: CLI tool for generating code based on GraphQL schemas and operations.

**@graphql-codegen/typescript**: designed to generate TypeScript code from your GraphQL schema

**@graphql-codegen/typescript-graphql-request**: creates functions and code that help you send queries, mutations, and subscriptions to a GraphQL server.

**@graphql-codegen/typescript-operations**: this is a template plugin

**@graphql-codegen/typescript-react-apollo**: this is a template plugin (we can specify different templates. As I mentioned in the very beginning code gen support for many frameworks and languages. If our requirement is to go with relay instead of Apollo, we can generate compatible code by adjusting these template plugins)

**@graphql-codegen/near-operation-file-preset**: generates operation typings per each operation file, near the original file of the operation

It's possible to generate hooks with `yarn generate-gql-queries` command. It will generate a single file (`./src/network/types.ts`) with hooks and models.

To remove code generation for GraphQL API it's needed to:

- delete some packages:

```bash
yarn remove @graphql-codegen/cli @graphql-codegen/typescript @graphql-codegen/typescript-graphql-request @graphql-codegen/typescript-operations @graphql-codegen/typescript-react-apollo @graphql-codegen/near-operation-file-preset
```

> **Note**: Make sure you have completed the [React Native - Environment Setup](https://reactnative.dev/docs/environment-setup) instructions till "Creating a new application" step, before proceeding.

## Step 1: Start the Metro Server

First, you will need to start **Metro**, the JavaScript _bundler_ that ships _with_ React Native.

To start Metro, run the following command from the _root_ of your React Native project:

```bash
# using npm
npm start

# OR using Yarn
yarn start
```

## Step 2: Start your Application

Let Metro Bundler run in its _own_ terminal. Open a _new_ terminal from the _root_ of your React Native project. Run the following command to start your _Android_ or _iOS_ app:

### For Android

```bash
# using npm
npm run android

# OR using Yarn
yarn android
```

### For iOS

```bash
# using npm
npm run ios

# OR using Yarn
yarn ios
```

If everything is set up _correctly_, you should see your new app running in your _Android Emulator_ or _iOS Simulator_ shortly provided you have set up your emulator/simulator correctly.

This is one way to run your app — you can also run it directly from within Android Studio and Xcode respectively.

## Step 3: Modifying your App

Now that you have successfully run the app, let's modify it.

1. Open `App.tsx` in your text editor of choice and edit some lines.
2. For **Android**: Press the <kbd>R</kbd> key twice or select **"Reload"** from the **Developer Menu** (<kbd>Ctrl</kbd> + <kbd>M</kbd> (on Window and Linux) or <kbd>Cmd ⌘</kbd> + <kbd>M</kbd> (on macOS)) to see your changes!

   For **iOS**: Hit <kbd>Cmd ⌘</kbd> + <kbd>R</kbd> in your iOS Simulator to reload the app and see your changes!

## Congratulations! :tada:

You've successfully run and modified your React Native App. :partying_face:

### Now what?

- If you want to add this new React Native code to an existing application, check out the [Integration guide](https://reactnative.dev/docs/integration-with-existing-apps).
- If you're curious to learn more about React Native, check out the [Introduction to React Native](https://reactnative.dev/docs/getting-started).

# Troubleshooting

If you can't get this to work, see the [Troubleshooting](https://reactnative.dev/docs/troubleshooting) page.

# Learn More

To learn more about React Native, take a look at the following resources:

- [React Native Website](https://reactnative.dev) - learn more about React Native.
- [Getting Started](https://reactnative.dev/docs/environment-setup) - an **overview** of React Native and how setup your environment.
- [Learn the Basics](https://reactnative.dev/docs/getting-started) - a **guided tour** of the React Native **basics**.
- [Blog](https://reactnative.dev/blog) - read the latest official React Native **Blog** posts.
- [`@facebook/react-native`](https://github.com/facebook/react-native) - the Open Source; GitHub **repository** for React Native.

## Based by

- [i18n](https://levelup.gitconnected.com/how-to-translate-react-native-apps-to-different-languages-76784c291ac8)
- [graphql codegen apollo](https://medium.com/ascentic-technology/supercharge-your-react-native-app-with-graphql-codegen-strongly-typed-hassle-free-data-fetching-ac262999af65)
- [folder structure](https://medium.com/@svbala99/react-native-boilerplate-2023-typescript-folder-structure-setup-bottom-tab-navigation-rn-691805025cd2)

## Troubleshooting husky
[Command not found](https://typicode.github.io/husky/troubleshooting.html#command-not-found)